@@ -5,5 +5,5 @@ from cratis.app.i18n.utils import localize_url as _
 
 urlpatterns = patterns('',
 
-    url(_(r'^profile/$'), 'allauth.account.views.email', name='profile')
+    url(_(r'^profile/$'), 'cratis.app.profile.views.profile', name='profile')
 )
