@@ -5,9 +5,7 @@ import logging
 import os
 
 from configurations import Configuration, values
-from pywizard.decorators import resource_set
 import sys
-from pywizard.worker import worker
 
 
 class Common(Configuration):
